/*
 * manhattan - logger.c
 *
 * Copyright (C) 2012  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <stdio.h>
#include <stdarg.h>
#include <pu-lib.h>

#ifdef HAVE_SYSLOG_H
extern int use_syslog;
#else
#define use_syslog (0)
#define openlog(ident, option, facility)	do { } while (0)
#define vsyslog(priority, fmt...)	do { } while (0)
#endif

void logger_init(void)
{
	if (use_syslog)
		openlog("pu-server", LOG_PID, LOG_DAEMON);
}

void log_printk(int priority, const char *fmt, ...)
{
	va_list ap;

	if (use_syslog) {
		va_start(ap, fmt);
		vsyslog(priority, fmt, ap);
		va_end(ap);
	} else {
		va_start(ap, fmt);
		vfprintf(stderr, fmt, ap);
		va_end(ap);
	}
}
